@@ -1,4 +1,4 @@
-// $Id: genres.h,v 1.1.1.1 2005/11/04 09:07:01 khlut Exp $
+// $Id: genres.h,v 1.2 2006/02/03 21:43:08 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -83,7 +83,7 @@ void PR_CALLBACK observer_thread( PD* );
 PLEvent * strevent(PD * pd, const char * str);
 bool post_event_to_thread( PRThread *receiver, PLEvent *(*allocator)(PD * pd, const char * str), PD * pd, const char * str );
 bool process_pending_events(void *owner);
-int run_slave( PD * pd, char *mime );
+int run_slave( PD * pd, char *mime, int restart );
 char *get_mime_list();
 char *find_slave(char *mime);
 void wait_slave(PD * pd);
