@@ -1,4 +1,4 @@
-// $Id: main_thread.c,v 1.4 2006/02/01 22:47:51 khlut Exp $
+// $Id: main_thread.c,v 1.5 2006/02/03 21:43:08 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -111,7 +111,7 @@ void send_value(PD *pd, char *key, char *value) //send variable to slave
     PR_Unlock(pd->lock);
     wait_slave(pd);
     pd->status=Init;
-    run_slave(pd,pd->mime);	// run slave parallel process
+    run_slave(pd,pd->mime,1);	// run slave parallel process
     
     // slave observer thread
     if(!( pd->observer=PR_CreateThread(PR_USER_THREAD, (void (*)(void*))&observer_thread,
@@ -263,11 +263,11 @@ NPError NP_GetValue(void *future, NPPVariable variable, void *value)
   printf("NP_GETVALUE\n");
   switch (variable) {
     case NPPVpluginNameString:
-      *((char **) value) = "The GenReS Mozilla plugin V 0.8.0";
+      *((char **) value) = "The GenReS Mozilla plugin V 0.8.1";
       break;
     case NPPVpluginDescriptionString:
       *((char **) value) = "<a href=https://savannah.nongnu.org/projects/genres>GENeric REconfigureable Scriptable plugin</a> for Mozilla/Firefox<br>"
-    			   "Version 0.8.0<br>"
+    			   "Version 0.8.1<br>"
 			   "Author: Sergey Khlutchin<br>"
 			   LICENSE;
       break;
@@ -346,7 +346,7 @@ NPError NPP_New(NPMIMEType mime, NPP instance, uint16 mode, int16 argc,
     pd->lock=PR_NewLock();
     pd->status=Init;
     pd->mime=strdup(mime);
-    run_slave(pd,mime);	// run slave parallel process
+    run_slave(pd,mime,0);	// run slave parallel process
     
     // slave observer thread
     if(!( pd->observer=PR_CreateThread( PR_USER_THREAD, (void (*)(void*))&observer_thread,
@@ -404,7 +404,7 @@ void wait_slave(PD * pd) { // wait for slave termination
     printf("wait %d\n",pd->slave);
     if(waitpid(pd->slave,&i,WNOHANG)<0) perror("wait");
     printf("wait observer\n");
-    PR_JoinThread(pd->observer);
+    if(pd->observer) {PR_JoinThread(pd->observer); pd->observer=0;}
     if(pd->slavectrl) {fclose(pd->slavectrl); pd->slavectrl=0;}
     printf("Process events %x\n", (int)pd->instance);
     process_pending_events(pd);
