@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.4 2005/11/20 05:16:06 khlut Exp $
+# $Id: mplayer.pl,v 1.10 2006/02/03 23:41:58 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 #
 # Copyright 2005 Elphel, Inc.
@@ -51,22 +51,28 @@ $v{timeout}=10;    #shut down mplayer after 10 seconds of silent
 $v{quittimeout}=2; #wait 2 seconds after send quit command or interruptable signal
 $v{play}=1;
 
-$|=1;
+$|=1; #forces a flush right away and after every write or print on the currently selected output channel
 my $shutstate:shared=0;
 my $pausestate:shared=0;
 my $queue:shared="";
 my $thrid:shared;
 
+$^F=100; #to pass pipe to new processes
+pipe PIPE_OUT, PIPE_IN;
+
 sub shut{
     lock $queue,$shutstate;
     !$shutstate++ && $v{save} && $shutstate++;
     alarm $v{quittimeout};
     if($shutstate==1){		#interrupt read
 	print SLVW "\nquit\n";
+	close(PIPE_IN);
     }elsif($shutstate==2){	#tell mplayer to shut
         kill 2 => $slvp;
+	kill 2 => $sl2p if $sl2p;
     }else{			#if it again not respond kill it
         kill -9 => $slvp;
+	kill -9 => $sl2p if $sl2p;
 	print "\nrun=0\n";    
 	exit 0;	
     }
@@ -77,9 +83,14 @@ sub normal_exit{
     $SIG{PIPE}='IGNORE';
     lock $queue,$shutstate;
     alarm $v{$shutstate?'quittimeout':'timeout'};
+    close(PIPE_IN);
     waitpid $slvp, 0;
     waitpid $slvp, 0;
     waitpid $slvp, 0;
+    kill 2 => $sl2p if $sl2p;
+    waitpid($sl2p, 0) if $sl2p;
+    waitpid($sl2p, 0) if $sl2p;
+    waitpid($sl2p, 0) if $sl2p;
     if(waitpid($slvp, 0)<0 && kill(0,$slvp)>0 && threads->self->tid == $thrid) {
 	alarm 0;
 	return;
@@ -99,8 +110,9 @@ sub ifilt{
 	lock $queue;
 	$queue.="pause=1\nplay=0\n";
     }
-    while(<>){
-	($var,$val)= split '=';
+    while(<STDIN>){
+	($var,$val)= split '=', $_, 2;
+	$val=~s/\n//;
 	if( $_ eq "run=0\n" ) {
 	    shut();
 	    last;
@@ -113,8 +125,15 @@ sub ifilt{
 		lock $queue;
 		$queue.="pause=$val\nplay=".(1-$val)."\n";
 	    }	    
+	}elsif( $var eq "src" or $var eq "href") {
+	    $v{href}=$val;
+	    print SLVW "loadfile $val\n";
+	    lock $queue;
+	    $queue.="$_";
 	}else{
-	    print SLVW;
+	    $v{$var}=$val;
+	    lock $queue;
+	    $queue.="$_";
 	}
     }
 }
@@ -144,7 +163,15 @@ sub ofilt{
 	}
 	if($_ eq "\n") {
 	    if( $s =~ 'Failed' ) {
-	        print "error=$s"
+	        print "error=$s";
+	    }elsif($s =~ m/^Playing \(.*\)\.$/){
+		$s=$1;
+		if($s !~ m!-|/dev!) {
+		    $s="file://".$s if $s !~ m|^[a-z0-9]*://|;
+		    print "url=$s";
+		}
+	    }elsif($s =~ m/^[AV]:/ || $s =~ m/^Pos:/){
+		print "frame=$s";
 	    }else{
 		print $s;
 	    }
@@ -181,9 +208,9 @@ print "pause=0\n", # list of control variables
       "fps=\n",
       "lowres=\n",
       "src=\n",
-      "href=\n";
+      "href=\n" unless($ARGV[0] eq '--no-vars');
       
-while (<>){
+while (<STDIN>){
     s/\n//;
     if($_ !~ /.*=/){
 	print "error=1\n";
@@ -208,8 +235,12 @@ while (<>){
 		file_dialog(out_file, not_ask, frames) || next;
 		$out_file=$cfg{out_file}[0];
 	    }
-	    $restart=\&run_mencoder;
-	    run_mencoder();
+	    if($v{href} =~ m|^rtp://([0-9.]+):([0-9]+)/?$|) {
+		;
+	    } else {
+		$restart=\&run_mencoder;
+		run_mencoder();
+	    }
 	}else{
 	    if( $v{xid} ) {
 		$OPTS.=" -wid 0x$v{xid}";
@@ -222,9 +253,18 @@ while (<>){
 	    $OPTS.=" -lavdopts lowres='$v{lowres}'" if( $v{lowres} );
 	    $OPTS.=" -fps '$v{fps}'"		if( $v{fps} );
 	    $OPTS.=" -fixed-vo -loop ".(0+$v{loop}) if( exists $v{loop} );
-	    $cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies '$v{href}'";
-	    print "cmd=$cmd\n";
-	    runslv $cmd;
+	    if($v{type} =~ m|^video/m| && $v{href} =~ m|^rtp://([0-9.]+):([0-9]+)/?$| ) {
+	        $cmd2="|exec ElphelOgm -a $1 -p $2 2>/dev/null >/dev/fd/".fileno(PIPE_IN);
+		$cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies -nocache /dev/fd/".fileno(PIPE_OUT);
+	        print "cmd=$cmd\n";
+	        print "cmd2=$cmd2\n";
+		runslv $cmd;		
+		$sl2p=open(SL2W,$cmd2);
+	    } else {
+		$cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies '$v{href}'";
+	        print "cmd=$cmd\n";
+	        runslv $cmd;
+	    }
 	}
 	$ifilt=$$;
 	$thrid = threads->new(\&ofilt)->tid;
@@ -235,5 +275,6 @@ while (<>){
 	last;
     }else{
 	print "$_\n";
+	if($x eq "href") { print "src=$y\n"; }
     }
 }
